#version 330 core
layout (location = 0) out vec4 FragColor;
layout (location = 1) out vec4 BrightColor;

struct Material {
    vec3 ambient;
    vec3 diffus;
    vec3 specular;
    float shininess;
}
;
struct Light {
    vec3 direction;
    vec3 ambient;
    vec3 diffuse;
    vec3 specular;
};

in vec3 FragPos;
in vec3 Normal;

uniform vec3 viewPos;
uniform Material material;
uniform Light light;
void main()
{
	vec3 norm = normalize(Normal);
    vec3 lightDir = normalize(-light.direction);

    // Diffuse shading
    float diff = max(dot(norm, lightDir), 0.0);

    // Combine results
    vec3 ambient = light.ambient * material.ambient;
    vec3 diffuse = light.diffuse * (diff * material.diffus);
  
	// Specular 
	vec3 viewDir = normalize(viewPos - FragPos);
   // vec3 reflectDir = reflect(-lightDir, norm);
    vec3 halfwayDir = normalize(lightDir + viewDir); 
    float spec = pow(max(dot(norm, halfwayDir), 0.0), material.shininess);
    vec3 specular = light.specular * (spec * material.specular);
    
	vec3 result = ambient + diffuse + specular;
    // check whether result is higher than some threshold, if so, output as bloom threshold color
    float brightness = dot(result, vec3(0.2126, 0.7152, 0.0722));
    if(brightness > 2.0)
        BrightColor = vec4(result, 1.0);
	else
		BrightColor = vec4(0.0f, 0.0f, 0.0f, 1.0f);
    FragColor = vec4(result, 1.0);
}